tdTheme <- function(pch = 21:25,
                    col.points = brewer.pal(n= 8, 'Dark2'),
                    fill = brewer.pal(n= 8, 'Pastel2'),
                    cex = 1.1,
                    ...){
    simpleTheme(pch = pch,
                col.points = col.points,
                fill = fill,
                cex = cex,
                ...)
}
